@@ -5,6 +5,7 @@ from devsecops_engine_tools.engine_core.src.domain.model.finding import (
 from datetime import datetime
 from dataclasses import dataclass
 
+
 @dataclass
 class CheckovDeserealizator:
     @classmethod
@@ -16,20 +17,24 @@ class CheckovDeserealizator:
         for result in results_scan_list:
             if "failed_checks" in str(result):
                 for scan in result["results"]["failed_checks"]:
-                    check_id = scan.get("check_id") 
+                    check_id = scan.get("check_id")
                     if not rules.get(check_id):
                         description = scan.get("check_name")
                         severity = default_severity.lower()
                         category = default_category.lower()
                     else:
-                        description = rules[check_id].get("checkID", scan.get("check_name"))
+                        description = rules[check_id].get(
+                            "checkID", scan.get("check_name")
+                        )
                         severity = rules[check_id].get("severity").lower()
                         category = rules[check_id].get("category").lower()
 
                     finding_open = Finding(
                         id=check_id,
                         cvss=None,
-                        where=scan.get("repo_file_path") + ": " + str(scan.get("resource")),
+                        where=scan.get("repo_file_path")
+                        + ": "
+                        + str(scan.get("resource")),
                         description=description,
                         severity=severity,
                         identification_date=datetime.now().strftime("%d%m%Y"),
@@ -37,10 +42,8 @@ class CheckovDeserealizator:
                         module="engine_iac",
                         category=Category(category),
                         requirements=scan.get("guideline"),
-                        tool="Checkov"
+                        tool="Checkov",
                     )
-                    list_open_findings.append(finding_open)      
-       
+                    list_open_findings.append(finding_open)
+
         return list_open_findings
-    
-    
\ No newline at end of file
