@@ -7,11 +7,11 @@ class ImagesGateway(metaclass=ABCMeta):
         "get image to scan"
 
     @abstractmethod
-    def get_base_image(self, image_to_scan) -> str:
+    def get_base_image(self, image_to_scan, base_image_labels: list, label_keys: dict = None) -> str:
         "get base image"
 
     @abstractmethod
-    def validate_base_image_date(self, image_to_scan, referenced_date) -> str:
+    def validate_base_image_date(self, image_to_scan, referenced_date, base_image_labels: list, label_keys: dict = None) -> str:
         "validate base image date"
     
     @abstractmethod
