@@ -16,7 +16,7 @@ logger = MyLogger.__call__(**settings.SETTING_LOGGER).get_logger()
 
 class TrivyScan(ToolGateway):
 
-    def scan_image(self, prefix, image_name, result_file, base_image, is_compressed_file=False):
+    def scan_image(self, prefix, image_name, result_file, base_image, vuln_type, ignore_unfixed=False, is_compressed_file=False):
         command = [
             prefix,
             "--scanners",
@@ -25,7 +25,12 @@ class TrivyScan(ToolGateway):
             "json",
             "-o",
             result_file,
+            "--pkg-types",
+            vuln_type
         ]
+
+        if ignore_unfixed:
+            command.append("--ignore-unfixed")
         
         if is_compressed_file:
             command.extend(["--quiet", "image", "--input", image_name])
@@ -47,7 +52,7 @@ class TrivyScan(ToolGateway):
         except Exception as e:
             logger.error(f"Error during image scan of {image_name}: {e}")
 
-    def _generate_sbom(self, prefix, image_name, remoteconfig, is_compressed_file=False):
+    def _generate_sbom(self, prefix, image_name, remoteconfig, vuln_type, ignore_unfixed=False, is_compressed_file=False):
         result_sbom = f"{image_name.replace('/', '_')}_SBOM.json"
         command = [
             prefix,
@@ -55,8 +60,12 @@ class TrivyScan(ToolGateway):
             "--format",
             remoteconfig["TRIVY"]["SBOM_FORMAT"],
             "--output",
-            result_sbom
+            result_sbom,
+            "--pkg-types",
+            vuln_type
         ]
+        if ignore_unfixed:
+            command.append("--ignore-unfixed")
         if is_compressed_file:
             command.extend(["--quiet", "--input", image_name])
         else:
@@ -77,7 +86,10 @@ class TrivyScan(ToolGateway):
             logger.error(f"Error generating SBOM: {e}")
 
     def run_tool_container_sca(self, remoteconfig, secret_tool, token_engine_container, image_name, result_file, base_image, exclusions, generate_sbom, is_compressed_file=False):
-        trivy_version = remoteconfig["TRIVY"]["TRIVY_VERSION"]        
+        trivy_version = remoteconfig["TRIVY"]["TRIVY_VERSION"]
+        vuln_type = remoteconfig["TRIVY"].get("VULN_TYPE", "all").lower()
+        vuln_type = vuln_type if vuln_type in ["os", "library"] else "os,library"
+        ignore_unfixed = remoteconfig["TRIVY"].get("IGNORE_UNFIXED", False)      
         command_prefix = TrivyManagerScanUtils().identify_os_and_install(trivy_version)
         sbom_components = None
         
@@ -85,9 +97,9 @@ class TrivyScan(ToolGateway):
             return None
 
         image_scanned = (
-            self.scan_image(command_prefix, image_name, result_file, base_image, is_compressed_file)
+            self.scan_image(command_prefix, image_name, result_file, base_image, vuln_type, ignore_unfixed, is_compressed_file)
         )
         if generate_sbom:
-            sbom_components = self._generate_sbom(command_prefix, image_name, remoteconfig, is_compressed_file)
+            sbom_components = self._generate_sbom(command_prefix, image_name, remoteconfig, vuln_type, ignore_unfixed, is_compressed_file)
 
         return image_scanned, sbom_components
